@@ -88,6 +88,8 @@ CREATE TABLE `ja_jobnet_control_table` (
         `user_name`                       varchar(100)             DEFAULT ''      NOT NULL,
         `jobnet_name`                     varchar(64)              DEFAULT ''      NOT NULL,
         `memo`                            varchar(100)                             NULL,
+        `jobnet_timeout`                  integer                  DEFAULT '0'     NOT NULL,
+        `timeout_run_type`                integer                  DEFAULT '0'     NOT NULL,
 CONSTRAINT `ja_jobnet_control_pk` PRIMARY KEY (`jobnet_id`,`update_date`)
 ) ENGINE=InnoDB;
 
@@ -265,6 +267,7 @@ CREATE TABLE `ja_icon_job_table` (
         `timeout`                         integer                  DEFAULT '0'     NOT NULL,
         `host_name`                       varchar(128)             DEFAULT ''      NOT NULL,
         `stop_code`                       varchar(32)                              NULL,
+        `timeout_run_type`                integer                  DEFAULT '0'     NOT NULL,
 CONSTRAINT `ja_icon_job_pk` PRIMARY KEY (`jobnet_id`,`job_id`,`update_date`)
 ) ENGINE=InnoDB;
 
@@ -408,6 +411,9 @@ CREATE TABLE `ja_run_jobnet_summary_table` (
         `virtual_end_time`                bigint unsigned          DEFAULT '0'     NOT NULL,
         `start_pending_flag`              integer                  DEFAULT '0'     NOT NULL,
         `initial_scheduled_time`          bigint unsigned          DEFAULT '0'     NOT NULL,
+        `jobnet_timeout`                  integer                  DEFAULT '0'     NOT NULL,
+        `timeout_run_type`                integer                  DEFAULT '0'     NOT NULL,
+        `jobnet_timeout_flag`             integer                  DEFAULT '0'     NOT NULL,
 CONSTRAINT `ja_run_jobnet_summary_pk` PRIMARY KEY (`inner_jobnet_id`)
 ) ENGINE=InnoDB;
 
@@ -623,6 +629,7 @@ CREATE TABLE `ja_run_icon_job_table` (
         `timeout`                         integer                  DEFAULT '0'     NOT NULL,
         `host_name`                       varchar(128)             DEFAULT ''      NOT NULL,
         `stop_code`                       varchar(32)                              NULL,
+        `timeout_run_type`                integer                  DEFAULT '0'     NOT NULL,
 CONSTRAINT `ja_run_icon_job_pk` PRIMARY KEY (`inner_job_id`)
 ) ENGINE=InnoDB;
 
