@@ -44,6 +44,15 @@ char* FILE_EXT[] = { "json", "bat", "start", "end", "ret", "stdout", "stderr", N
 char* FILE_EXT[] = { "json", "sh", "start", "end", "ret", "stdout", "stderr", NULL };
 #endif
 
+//common global variable for folder path.
+char JA_EXEC_FOLDER[JA_FILE_PATH_LEN];
+char JA_END_FOLDER[JA_FILE_PATH_LEN];
+char JA_DATA_FOLDER[JA_FILE_PATH_LEN];
+char JA_ERROR_FOLDER[JA_FILE_PATH_LEN];
+char JA_BEGIN_FOLDER[JA_FILE_PATH_LEN];
+char JA_CLOSE_FOLDER[JA_FILE_PATH_LEN];
+
+
 int ja_jobfile_move(char *src_folder,char *dest_folder,char *filename){
 	int createFolder;
 	char dest_file[JA_FILE_PATH_LEN];
@@ -201,7 +210,6 @@ int ja_jobfile_remove(const char *filename)
     char* pid_char;
     int move_check, i, j;
     char full_filename[JA_MAX_STRING_LEN];
-    char filepath[JA_FILE_PATH_LEN];
     char prefix_data_file_name[JA_FILE_PATH_LEN];
     char close_new_folder_path[JA_FILE_PATH_LEN];
     const char *__function_name = "ja_jobfile_remove";
@@ -209,9 +217,8 @@ int ja_jobfile_remove(const char *filename)
     zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
 
     move_check = SUCCEED;
-    zbx_snprintf(close_new_folder_path, sizeof(close_new_folder_path), "%s%c%s%c%s", CONFIG_TMPDIR, JA_DLM, "close",JA_DLM,filename);
-    zbx_snprintf(filepath, sizeof(filepath), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "data");
-    zabbix_log(LOG_LEVEL_DEBUG, "In %s() filepath: %s and archive folder in close : %s", __function_name, filepath,close_new_folder_path);
+    zbx_snprintf(close_new_folder_path, sizeof(close_new_folder_path), "%s%c%s", JA_CLOSE_FOLDER,JA_DLM,filename);
+    zabbix_log(LOG_LEVEL_DEBUG, "In %s() filepath: %s and archive folder in close : %s", __function_name, JA_DATA_FOLDER,close_new_folder_path);
 
     ///move data file to close/~~~ folder.
     pid_char = strrchr(filename, '-');
@@ -225,7 +232,7 @@ int ja_jobfile_remove(const char *filename)
         else {
             zbx_snprintf(full_filename, sizeof(full_filename), "%s.%s", filename, FILE_EXT[i]);
         }
-        move_check = ja_jobfile_move(filepath,close_new_folder_path,full_filename);
+        move_check = ja_jobfile_move(JA_DATA_FOLDER,close_new_folder_path,full_filename);
         if (move_check == FAIL) {
             j = 0;
             while (j < i+1) {
@@ -235,7 +242,7 @@ int ja_jobfile_remove(const char *filename)
                 else {
                     zbx_snprintf(full_filename, sizeof(full_filename), "%s.%s", filename, FILE_EXT[j]);
                 }
-                ja_jobfile_move(close_new_folder_path, filepath, full_filename);
+                ja_jobfile_move(close_new_folder_path, JA_DATA_FOLDER, full_filename);
                 j++;
             }
             i = 0;
@@ -362,21 +369,23 @@ int ja_jobfile_load(const char *filepath, ja_job_object * job)
 
     return SUCCEED;
 }
-int ja_jobfile_check_processexist(char *filename,char *jobid_datetime) {
+int ja_jobfile_check_processexist(char *filename,char *full_filename) {
+    size_t len;
+    char jobid_datetime[JA_FILE_NAME_LEN];
     int proc_run_flag = 0, tmp_flg = 0;
-    char exec_folder[JA_FILE_PATH_LEN];
     DIR* exec_dir;
     struct dirent* entry;
     const char* __function_name = "ja_jobfile_check_processexist";
 
     zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
-    exec_folder[0] = '\0';
-    zbx_snprintf(exec_folder, sizeof(exec_folder), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec");
-    exec_dir = opendir(exec_folder);
+
+    len = strlen(full_filename);
+    zbx_strlcpy(jobid_datetime, full_filename, len - 3);
+    exec_dir = opendir(JA_EXEC_FOLDER);
     if (exec_dir == NULL)
     {
-        zabbix_log(LOG_LEVEL_ERR, " In%s()  exec folder [%s] cannot be opened.", __function_name, exec_folder);
+        zabbix_log(LOG_LEVEL_ERR, " In%s()  exec folder [%s] cannot be opened.", __function_name, JA_EXEC_FOLDER);
         proc_run_flag = 0;
         goto contd;
 
@@ -554,22 +563,22 @@ error:
     return ret;
 }
 
-int job_to_error(char* src_folder, char* filename) {
+int job_to_error(char* src_folder, char* full_filename) {
     int i = 0;
+    size_t len=0;
     int folder_create_flg,ii,jj;
-    char error_folder[JA_FILE_PATH_LEN];
     char error_sub_folder[JA_FILE_PATH_LEN];
     char close_sub_folder[JA_FILE_PATH_LEN];
     char src_file[JA_FILE_PATH_LEN];
     char dest_file[JA_FILE_PATH_LEN];
     char data_filename[JA_FILE_PATH_LEN];
     char data_file[JA_FILE_PATH_LEN];
-    char data_folder[JA_FILE_PATH_LEN];
+    char filename[JA_FILE_PATH_LEN];
     struct stat      stat_buf;
     const char* __function_name = "job_to_error";
 
 
-    zabbix_log(LOG_LEVEL_INFORMATION, "In %s() [%s] file and it's data files will be moved to error folder.", __function_name, filename);
+    zabbix_log(LOG_LEVEL_INFORMATION, "In %s() [%s] file and it's data files will be moved to error folder.", __function_name, full_filename);
 
 
     if (src_folder == NULL) {
@@ -577,22 +586,20 @@ int job_to_error(char* src_folder, char* filename) {
         return FAIL;
     }
 
-    zbx_snprintf(error_folder, sizeof(error_folder), "%s%cerror", CONFIG_TMPDIR, JA_DLM);
-    zbx_snprintf(data_folder, sizeof(data_folder), "%s%cdata", CONFIG_TMPDIR, JA_DLM);
-    //create sub-folder
-
+    len = strlen(full_filename);
+    zbx_strlcpy(filename, full_filename, len - 3);
 #ifdef _WINDOWS
-    folder_create_flg = _mkdir(error_folder);
+    folder_create_flg = _mkdir(JA_ERROR_FOLDER);
 #else
-    folder_create_flg = mkdir(error_folder, JA_PERMISSION);
+    folder_create_flg = mkdir(JA_ERROR_FOLDER, JA_PERMISSION);
 #endif
     //if folder create fail without an existing folder
     if (folder_create_flg != 0 && errno != EEXIST) {
-        zabbix_log(LOG_LEVEL_ERR, "cannot create error folder.Path: %s", error_folder);
+        zabbix_log(LOG_LEVEL_ERR, "cannot create error folder.Path: %s", JA_ERROR_FOLDER);
         return FAIL;
     }
-    zbx_snprintf(error_sub_folder, sizeof(error_sub_folder), "%s%cerror%c%s", CONFIG_TMPDIR, JA_DLM,JA_DLM,filename);
-    zbx_snprintf(close_sub_folder, sizeof(close_sub_folder), "%s%cclose%c%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, filename);
+    zbx_snprintf(error_sub_folder, sizeof(error_sub_folder), "%s%c%s",JA_ERROR_FOLDER,JA_DLM,filename);
+    zbx_snprintf(close_sub_folder, sizeof(close_sub_folder), "%s%c%s", JA_CLOSE_FOLDER, JA_DLM, filename);
 #ifdef _WINDOWS
     folder_create_flg = _mkdir(error_sub_folder);
 #else
@@ -625,7 +632,7 @@ int job_to_error(char* src_folder, char* filename) {
         }
         zbx_snprintf(dest_file, sizeof(dest_file), "%s%c%s", error_sub_folder,JA_DLM,data_filename);
 
-        zbx_snprintf(src_file, sizeof(src_file), "%s%c%s", data_folder, JA_DLM, data_filename);
+        zbx_snprintf(src_file, sizeof(src_file), "%s%c%s", JA_DATA_FOLDER, JA_DLM, data_filename);
         //log for file move warning and information fix
         //
         if (0 != rename(src_file, dest_file)) {
@@ -651,7 +658,7 @@ int job_to_error(char* src_folder, char* filename) {
     }
 
     if (0 == rmdir(close_sub_folder)) {
-        zabbix_log(LOG_LEVEL_INFORMATION, "In %s() [%s] deleted folder.", __function_name, close_sub_folder);
+        zabbix_log(LOG_LEVEL_DEBUG, "In %s() [%s] deleted folder.", __function_name, close_sub_folder);
     }
     else {
         if (stat(close_sub_folder, &stat_buf) == 0) {
@@ -664,11 +671,11 @@ int job_to_error(char* src_folder, char* filename) {
     }
     //move job file to error folder.
     zbx_snprintf(src_file, sizeof(src_file), "%s.%s",filename , "job");
-    if (FAIL == ja_jobfile_move(src_folder, error_folder, src_file)) {
+    if (FAIL == ja_jobfile_move(src_folder, JA_ERROR_FOLDER, src_file)) {
         zabbix_log(LOG_LEVEL_ERR, "In %s() cannot move file from %s to error folder.", __function_name, src_folder);
         return FAIL;
     }
-    zabbix_log(LOG_LEVEL_INFORMATION, "In %s() move[%s] file from %s to %s folder.", __function_name, src_file, src_folder, error_folder);
+    zabbix_log(LOG_LEVEL_INFORMATION, "In %s() move[%s] file from %s to %s folder.", __function_name, src_file, src_folder, JA_ERROR_FOLDER);
     return SUCCEED;
 }
 //count nubmer of files in a folder.Return success/failure value.
@@ -698,3 +705,40 @@ int get_file_count(char* folder) {
     }
     return sub_files_count;
 }
+void ja_jobfile_fullpath(char* full_filename, int folder_type, char* result_filepath) {
+    char tmp_filename[JA_FILE_NAME_LEN];
+    const char* __function_name = "ja_jobfile_fullpath";
+
+    zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
+    tmp_filename[0] = '\0';
+    if (full_filename == NULL) {
+        zabbix_log(LOG_LEVEL_ERR, "In %s(), file name is null.", __function_name);
+        return;
+    }
+    switch (folder_type) {
+    case JA_TYPE_STATUS_DATA:
+        get_jobid_datetime(full_filename, tmp_filename);
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s%s", JA_DATA_FOLDER, JA_DLM, tmp_filename, ".json");
+        break;
+
+    case JA_TYPE_STATUS_BEGIN:
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s", JA_BEGIN_FOLDER, JA_DLM, full_filename);
+        break;
+    case JA_TYPE_STATUS_EXEC:
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s", JA_EXEC_FOLDER, JA_DLM, full_filename);
+        break;
+    case JA_TYPE_STATUS_END:
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s", JA_END_FOLDER, JA_DLM, full_filename);
+        break;
+    case JA_TYPE_STATUS_CLOSE:
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s", JA_CLOSE_FOLDER, JA_DLM, full_filename);
+        break;
+    case JA_TYPE_STATUS_ERROR:
+        zbx_snprintf(result_filepath, JA_FILE_PATH_LEN, "%s%c%s", JA_ERROR_FOLDER, JA_DLM, full_filename);
+        break;
+    default:
+        zabbix_log(LOG_LEVEL_ERR, "In %s(), File type error.", __function_name);
+        break;
+    }
+    zabbix_log(LOG_LEVEL_DEBUG, "In %s(), result file name is : %s", __function_name,result_filepath);
+}
