@@ -587,7 +587,7 @@ int	ja_log(char *message_id, zbx_uint64_t inner_jobnet_id, char *jobnet_id, zbx_
 			str_inner_jobnet_main_id = zbx_dsprintf(NULL,"" ZBX_FS_UI64 "" ,inner_jobnet_main_id);
 			zbx_snprintf(cmd, sizeof(cmd), "%s/%s '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' &",
 				CONFIG_ERROR_CMD_PATH, dp->d_name, s_user_name, s_jobnet_id, now_date, message_id, type, message, host_name, s_job_id_full,str_inner_jobnet_main_id);
-			rc = system(cmd);
+			rc = ja_system_call(cmd);
 			zabbix_log(LOG_LEVEL_DEBUG, "application execution [%s] (%d)", cmd, rc);
 			zbx_free(str_inner_jobnet_main_id);
 			if (rc != EXIT_SUCCESS)
