@@ -89,7 +89,7 @@ ZBX_THREAD_ENTRY(executive_thread, args)
 		tm = localtime(&now);
 		if (0 == tm->tm_hour || 4 == tm->tm_hour || 8 == tm->tm_hour || 12 == tm->tm_hour || 16 == tm->tm_hour || 20 == tm->tm_hour) {
 			if (write_log == 0) {
-				zabbix_log(LOG_LEVEL_INFORMATION,"jobarg_agentd #%d running [executive]",thread_number);
+				zabbix_log(LOG_LEVEL_INFORMATION,"jobarg_agentd[%s (revision %s)] #%d running [executive]",JOBARG_VERSION, JOBARG_REVISION,thread_number);
 				write_log = 1;
 			}
 		}
@@ -125,15 +125,11 @@ int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files){
 	int ret = SUCCEED;
 	int i, job_per_sec = 10, data_file_count = 0, begin_file_count = 0, proc_run_flag = 0;
 	char data_file[JA_FILE_PATH_LEN];
-	char data_filepath[JA_FILE_PATH_LEN];
-	char begin_filepath[JA_FILE_PATH_LEN];
-	char exec_filepath[JA_FILE_PATH_LEN];
-	char data_filename[FILENAME_MAX];
-	char begin_filename[FILENAME_MAX];
 	char exec_file[FILENAME_MAX];
 	char begin_file[FILENAME_MAX];
 	char tmp_exec_file[JA_FILE_PATH_LEN];
 	char filename[FILENAME_MAX];
+	char tmp_filename[FILENAME_MAX];
 	FILE* fp;
 	const char *__function_name = "ja_job_check_beginfile";
 
@@ -142,10 +138,7 @@ int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files){
 	//[start]check all files from begin folder.//
 	///get pid from file name
 	data_file[0] = '\0';
-	zbx_snprintf(data_filepath, sizeof(data_filepath), "%s%c%s", CONFIG_TMPDIR, JA_DLM,"data");
-	zbx_snprintf(begin_filepath, sizeof(begin_filepath), "%s%c%s", CONFIG_TMPDIR, JA_DLM,"begin");
-	zbx_snprintf(exec_filepath, sizeof(exec_filepath), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec");
-	if(read_all_files(begin_filepath, files,&begin_file_count)==FAIL){
+	if(read_all_files(JA_BEGIN_FOLDER, files,&begin_file_count)==FAIL){
 		ret=FAIL;
 		goto error;
 	}
@@ -155,18 +148,18 @@ int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files){
 		while(data_file_count<begin_file_count){
 			ja_job_object_init(job);
 			proc_run_flag = 0;
-			zbx_snprintf(begin_filename, sizeof(begin_filename), "%s",(files+data_file_count)->filename);
-			zbx_snprintf(begin_file, sizeof(begin_file), "%s%c%s", begin_filepath, JA_DLM, begin_filename);
-			zabbix_log(LOG_LEVEL_DEBUG, "In %s(), Processing [%s]", __function_name,begin_filename);
-			size_t len = strlen(begin_filename);
+			zbx_snprintf(filename, sizeof(filename), "%s",(files+data_file_count)->filename);
+			ja_jobfile_fullpath(filename, JA_TYPE_STATUS_BEGIN, begin_file);
+			zabbix_log(LOG_LEVEL_DEBUG, "In %s(), Processing [%s]", __function_name,filename);
+			size_t len = strlen(filename);
 			for (i = 0; i < len - 4;i++) {
-				filename[i] = begin_filename[i];
+				tmp_filename[i] = filename[i];
 			}
-			filename[i] = '\0';
+			tmp_filename[i] = '\0';
 			//add get accept_datetime for comparison.
-			zbx_snprintf(data_filename, sizeof(data_filename), "%s.json",filename);
-			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%s", exec_filepath, JA_DLM, filename,"-.job");
-			zbx_snprintf(data_file,sizeof(data_file), "%s%c%s",data_filepath,JA_DLM,data_filename);
+			zbx_snprintf(data_file, sizeof(data_file), "%s%c%s.json",JA_DATA_FOLDER,JA_DLM, tmp_filename);
+			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%s", JA_EXEC_FOLDER, JA_DLM, tmp_filename,"-.job");
+
 			if(read_datafile(job,data_file)==FAIL){
 				zabbix_log(LOG_LEVEL_ERR, "In %s()  job object data cannot be read from [%s] file.", __function_name, data_file);
 				fp = fopen(begin_file, "r");
@@ -175,7 +168,7 @@ int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files){
 					goto contd;
 				}
 				fclose(fp);
-				if (FAIL != job_to_error(begin_filepath, filename))
+				if (FAIL != job_to_error(JA_BEGIN_FOLDER, filename))
 					zabbix_log(LOG_LEVEL_WARNING, "[%s] ,along with the data files, are moved to error folder.", filename);
 				goto contd;
 			}
@@ -188,25 +181,25 @@ int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files){
 				if (data_file_count % job_per_sec == 0) {
 					zbx_sleep(1);
 				}
-				zabbix_log(LOG_LEVEL_INFORMATION, "In %s(),job id :"ZBX_FS_UI64"[%s] is found, and will be starting.", __function_name,job->jobid,begin_filename);
+				zabbix_log(LOG_LEVEL_INFORMATION, "In %s(),job id :"ZBX_FS_UI64"[%s] is found, and will be starting.", __function_name,job->jobid,filename);
 				//move files from begin to exec folder.
 				if (rename(begin_file, exec_file) != 0) {
 					//error moving files from begin folder to exec folder.
-					zabbix_log(LOG_LEVEL_ERR, "In %s(), %s file cannot be moved to %s folder. : %s", __function_name, begin_file, exec_filepath, strerror(errno));
+					zabbix_log(LOG_LEVEL_ERR, "In %s(), %s file cannot be moved to %s folder. : %s", __function_name, begin_file, JA_EXEC_FOLDER, strerror(errno));
 					goto contd;
 				}
 				ret = ja_agent_run(job, filename);
-				zabbix_log(LOG_LEVEL_INFORMATION, "In %s(),job id :"ZBX_FS_UI64"[%s] started and deleted begin file.", __function_name,job->jobid,begin_filename);
+				zabbix_log(LOG_LEVEL_INFORMATION, "In %s(),job id :"ZBX_FS_UI64"[%s] started and deleted begin file.", __function_name,job->jobid,filename);
 			}
 			else {
 				// Delete begin file 
 				zabbix_log(LOG_LEVEL_ERR, "In %s()  jobid: " ZBX_FS_UI64 " Job process is already running. process id : %d. delete [%s] file.", __function_name,job->jobid,job->pid,begin_file);
-				if (FAIL != job_to_error(begin_filepath, filename))
+				if (FAIL != job_to_error(JA_BEGIN_FOLDER, filename))
 					zabbix_log(LOG_LEVEL_WARNING, "[%s] ,along with the data files, are moved to error folder.", filename);
 			}
 			
 		contd:
-			zabbix_log(LOG_LEVEL_DEBUG, "In %s(), Processing [%s] finished.", __function_name, begin_filename);
+			zabbix_log(LOG_LEVEL_DEBUG, "In %s(), Processing [%s] finished.", __function_name,filename);
 			data_file_count++;
 		}
 	}
@@ -224,15 +217,13 @@ int ja_job_checkprocess(ja_job_object* job, ja_file_object* files){
 	JA_PID result_pid;
 	JA_PID child_pid;
 	int extcd, file_size, file_count = 0, loop_count = 0,fail_extcd = 137;
-	char folder[JA_FILE_PATH_LEN];
 	char check_file[JA_FILE_PATH_LEN];
 	char ret_file[JA_FILE_PATH_LEN];
 	char temp_pid[JA_FILE_NAME_LEN];
-	char current_filepath[JA_FILE_PATH_LEN];
+	char exec_file[JA_FILE_PATH_LEN];
 	char current_time[20];
 	char data_file[JA_FILE_PATH_LEN];
-	char proc_data_file[JA_FILE_PATH_LEN];
-	char jobid_date_fname[JA_FILE_PATH_LEN];
+	char proc_ret_file[JA_FILE_PATH_LEN];
 	char filename[JA_FILE_PATH_LEN];
 #ifdef _WINDOWS
 	DWORD exitCode = 0;
@@ -243,9 +234,8 @@ int ja_job_checkprocess(ja_job_object* job, ja_file_object* files){
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
 
 	temp_pid[0] = '\0';
-	zbx_snprintf(folder, sizeof(folder), "%s%cexec", CONFIG_TMPDIR, JA_DLM);
 		//open directory file and get filename;
-	if(read_all_files(folder, files,&file_count)==FAIL){
+	if(read_all_files(JA_EXEC_FOLDER, files,&file_count)==FAIL){
 		//above function read "all" job files in the exec filder, no job id or process id to be specific.
 		ret=FAIL;
 		goto error;
@@ -258,18 +248,16 @@ int ja_job_checkprocess(ja_job_object* job, ja_file_object* files){
 			///get pid from file name
 			zbx_snprintf(filename, sizeof(filename), "%s",(files+loop_count)->filename);
 			zabbix_log(LOG_LEVEL_DEBUG, "In %s() processing [%s]", __function_name,filename);
-			len = strlen(filename);
-			zbx_strlcpy(jobid_date_fname,filename,len-3);
-			get_jobid_datetime(jobid_date_fname,proc_data_file);
-			zbx_snprintf(data_file,sizeof(data_file), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, proc_data_file, ".json");
-			zbx_snprintf(current_filepath, sizeof(current_filepath), "%s%c%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, filename);
+			ja_jobfile_fullpath(filename, JA_TYPE_STATUS_DATA, data_file);
+			// [end] data file name creation
+			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s", JA_EXEC_FOLDER, JA_DLM, filename);
 			ja_jobfile_getpid_by_filename(filename, temp_pid);
 			if (temp_pid == NULL || temp_pid[0] == '\0' || atoi(temp_pid) == 0) {
 				zabbix_log(LOG_LEVEL_DEBUG, "In %s()  No pid yet in [%s] file.", __function_name,filename);
 				goto contd;
 			}
 			if (read_datafile(job, data_file) == FAIL) {
-				if(FAIL != job_to_error(folder, jobid_date_fname))
+				if(FAIL != job_to_error(JA_EXEC_FOLDER, filename))
 					zabbix_log(LOG_LEVEL_WARNING, "[%s] ,along with the data files, are moved to error folder.", filename);
 				goto contd;
 			}
@@ -317,7 +305,7 @@ int ja_job_checkprocess(ja_job_object* job, ja_file_object* files){
 				//child process exited.Check file size
 				zabbix_log(LOG_LEVEL_DEBUG, "In %s() child process executed. process id : %d", __function_name,child_pid);
 				file_size = 0;
-				zbx_snprintf(check_file, sizeof(check_file), "%s%c%s",folder,JA_DLM,filename);
+				zbx_snprintf(check_file, sizeof(check_file), "%s%c%s",JA_EXEC_FOLDER,JA_DLM,filename);
 				file_size = ja_file_getsize(check_file);
 				// if process exited and job file size ids less than 30, Write failed time and errorno to job file.
 				if(file_size<30)
@@ -342,7 +330,8 @@ int ja_job_checkprocess(ja_job_object* job, ja_file_object* files){
 #endif
 					fclose(fp);
 					//open ret file
-					zbx_snprintf(ret_file, sizeof(ret_file), "%s%cdata%c%s.ret",CONFIG_TMPDIR, JA_DLM,JA_DLM, jobid_date_fname);
+					get_jobid_datetime(proc_ret_file, filename);
+					zbx_snprintf(ret_file, sizeof(ret_file), "%s%cdata%c%s.ret",CONFIG_TMPDIR, JA_DLM,JA_DLM, proc_ret_file);
 					fp = fopen(ret_file,"wb");
 					if(fp!=NULL){
 						fwrite(&extcd, sizeof(extcd),1, fp);
@@ -363,14 +352,10 @@ error :
 int ja_job_exec_end(ja_job_object* job, ja_file_object* files){
 	int ret = SUCCEED;
 	int file_size, chk, file_count = 0, loop_count = 0;
-	char jobid_date_pid[JA_FILE_PATH_LEN];
-	char folder[JA_FILE_PATH_LEN];
 	char exec_file[JA_FILE_PATH_LEN];
-	char end_folder[JA_FILE_PATH_LEN];
 	char load_filepath[JA_FILE_PATH_LEN];
 	char load_filename[JA_FILE_PATH_LEN];
 	char temp_pid[JA_FILE_NAME_LEN];
-	char current_filepath[JA_FILE_PATH_LEN];
 	char prefix[JA_FILE_PATH_LEN];
 	char data_file[JA_FILE_PATH_LEN];
 	char filename[JA_FILE_PATH_LEN];
@@ -379,9 +364,8 @@ int ja_job_exec_end(ja_job_object* job, ja_file_object* files){
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
 
-	zbx_snprintf(folder, sizeof(folder), "%s%cexec", CONFIG_TMPDIR, JA_DLM);
 	temp_pid[0] = '\0';
-	if(read_all_files(folder,files,&file_count)==FAIL){
+	if(read_all_files(JA_EXEC_FOLDER,files,&file_count)==FAIL){
 		return FAIL;
 	}
 	if(file_count>0){
@@ -397,15 +381,12 @@ int ja_job_exec_end(ja_job_object* job, ja_file_object* files){
 				zabbix_log(LOG_LEVEL_DEBUG, "In %s()  No pid yet in [%s] file.", __function_name,filename);
 				goto end;
 			}
-			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s",folder,JA_DLM,filename);
+			ja_jobfile_fullpath(filename,JA_TYPE_STATUS_EXEC, exec_file);
 			file_size = ja_file_getsize(exec_file);
 			zabbix_log(LOG_LEVEL_DEBUG, "In %s(), [%s] file size : %d", __function_name,filename,file_size);
-			get_jobid_datetime(filename, prefix);
-			zbx_snprintf(jobid_date_pid, strlen(filename) - 3, "%s", filename);
-			zbx_snprintf(data_file, sizeof(data_file), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, prefix, ".json");
-			zbx_snprintf(current_filepath, sizeof(current_filepath), "%s%c%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, filename);
+			ja_jobfile_fullpath(filename, JA_TYPE_STATUS_DATA, data_file);
 			if (read_datafile(job, data_file) == FAIL) {
-				if(FAIL != job_to_error(folder, jobid_date_pid))
+				if(FAIL != job_to_error(JA_EXEC_FOLDER, filename))
 					zabbix_log(LOG_LEVEL_WARNING, "[%s] ,along with the data files, are moved to error folder.", filename);
 				goto end;
 			}
@@ -431,8 +412,7 @@ int ja_job_exec_end(ja_job_object* job, ja_file_object* files){
 			    }
 				if (job->result != JA_JOBRESULT_FAIL)
 					job->result = JA_JOBRESULT_SUCCEED;
-				zbx_snprintf(end_folder, sizeof(end_folder), "%s%cend", CONFIG_TMPDIR, JA_DLM);
-				if(ja_jobfile_move(folder,end_folder,filename)==FAIL){
+				if(ja_jobfile_move(JA_EXEC_FOLDER,JA_END_FOLDER,filename)==FAIL){
 					zabbix_log(LOG_LEVEL_ERR , "In %s() jobid: " ZBX_FS_UI64 ",[%s] file cannot be moved.",__function_name,job->jobid,filename);
 				}
 				zabbix_log(LOG_LEVEL_INFORMATION, "In %s(), job id : "ZBX_FS_UI64",total files read :%d, process id : %d finished.", __function_name,job->jobid,file_count,job->pid);
@@ -459,17 +439,12 @@ int ja_job_exec_end(ja_job_object* job, ja_file_object* files){
 int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 	int ret = SUCCEED;
 	int file_count = 0, loop_count = 0, close_status;
-	char folder[JA_FILE_PATH_LEN];
 	char end_file[JA_FILE_PATH_LEN];
-	char close_folder[JA_FILE_PATH_LEN];
-	char data_folder[JA_FILE_PATH_LEN];
 	char data_file[JA_FILE_PATH_LEN];
 	char load_filepath[JA_FILE_PATH_LEN];
 	char load_filename[JA_FILE_PATH_LEN];
 	char temp_pid[JA_FILE_NAME_LEN];
-	char current_filepath[JA_FILE_PATH_LEN];
 	char prefix[JA_FILE_PATH_LEN];
-	char jobid_date_pid[JA_FILE_PATH_LEN];
 	char tmp_src[JA_FILE_PATH_LEN];
 	char tmp_dest[JA_FILE_PATH_LEN];
 	char filename[JA_FILE_PATH_LEN];
@@ -481,9 +456,8 @@ int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
 
 
-	zbx_snprintf(folder, sizeof(folder), "%s%cend", CONFIG_TMPDIR, JA_DLM);
 	temp_pid[0] ='\0';
-	if (read_all_files(folder, files, &file_count) == FAIL) {
+	if (read_all_files(JA_END_FOLDER, files, &file_count) == FAIL) {
 		return FAIL;
 	}
 	if(file_count>0){
@@ -491,21 +465,14 @@ int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 		while(loop_count<file_count){
 			ja_job_object_init(job);
 			zbx_snprintf(filename, sizeof(filename), "%s",(files+loop_count)->filename);
-			zbx_snprintf(end_file, sizeof(end_file), "%s%c%s",folder,JA_DLM,filename);
-			
+			ja_jobfile_fullpath(filename, JA_TYPE_STATUS_END, end_file);
+			get_jobid_datetime(filename,prefix);
 			zabbix_log(LOG_LEVEL_DEBUG, "In %s() processing [%s]", __function_name, end_file);
-			zbx_snprintf(close_folder, sizeof(close_folder), "%s%cclose", CONFIG_TMPDIR, JA_DLM);
-			get_jobid_datetime(filename, prefix);
-			
-			//get job from data file
-			zbx_snprintf(data_folder, sizeof(data_folder), "%s%cdata", CONFIG_TMPDIR, JA_DLM);
-			zbx_snprintf(data_file, sizeof(data_file), "%s%c%s%s",data_folder,JA_DLM,prefix,".json");
+			ja_jobfile_fullpath(filename, JA_TYPE_STATUS_DATA, data_file);
 			zabbix_log(LOG_LEVEL_DEBUG, "In %s() load data file [%s]", __function_name,data_file);
-			zbx_snprintf(jobid_date_pid, strlen(filename) - 3, "%s", filename);
-			zbx_snprintf(current_filepath, sizeof(current_filepath), "%s%c%s%c%s", CONFIG_TMPDIR, JA_DLM, "end", JA_DLM, filename);
 			if (read_datafile(job,data_file) == FAIL || NULL == job) {
 
-				if(FAIL != job_to_error(folder, jobid_date_pid))
+				if(FAIL != job_to_error(JA_END_FOLDER, filename))
 					zabbix_log(LOG_LEVEL_WARNING, "[%s] ,along with the data files, are moved to error folder.", filename);
 				goto contd;
 			}
@@ -530,8 +497,8 @@ int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 				job->result = JA_JOBRESULT_SUCCEED;
 			if(ja_agent_close(job, filename) ==FAIL){
 				if (job->send_retry >= CONFIG_SEND_RETRY) {
-					job_to_error(folder, jobid_date_pid);
-					zbx_snprintf(data_file, sizeof(data_file), "%s%cerror%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, jobid_date_pid, JA_DLM, prefix, ".json");
+					job_to_error(JA_END_FOLDER, filename);
+					zbx_snprintf(data_file, sizeof(data_file), "%s%cerror%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, load_filename, JA_DLM, prefix, ".json");
 					zabbix_log(LOG_LEVEL_ERR, "In %s() agent close failed.%s", __function_name, job->message);
 				}
 				else {
@@ -541,7 +508,7 @@ int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 				}
 			}
 			else {
-				if (ja_jobfile_move(folder, close_folder, filename) == FAIL) {
+				if (ja_jobfile_move(JA_END_FOLDER, JA_CLOSE_FOLDER, filename) == FAIL) {
 					zabbix_log(LOG_LEVEL_ERR, "In %s() [%s] file cannot be moved.", __function_name, filename);
 					goto contd;
 				}
@@ -555,7 +522,7 @@ int ja_job_exec_close(ja_job_object* job, ja_file_object* files){
 				else {
 					//set datafile for close folder.
 					zabbix_log(LOG_LEVEL_INFORMATION, "In ja_jobfile_remove(),job id :"ZBX_FS_UI64"'s all data have been archived in close-folder.", job->jobid);
-					zbx_snprintf(data_file, sizeof(data_file), "%s%cclose%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, jobid_date_pid, JA_DLM, prefix, ".json");
+					zbx_snprintf(data_file, sizeof(data_file), "%s%cclose%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, load_filename, JA_DLM, prefix, ".json");
 				}
 			}
 		contd:
@@ -716,7 +683,6 @@ void ja_job_clean_exec(ja_job_object* job) {
 	DIR* dir;
 	struct dirent* entry;
 	FILE* fp;
-	char exec[JA_FILE_PATH_LEN];
 	char filename[JA_FILE_PATH_LEN];
 	char exec_file[JA_FILE_PATH_LEN];
 	char data_file[JA_FILE_PATH_LEN];
@@ -728,11 +694,10 @@ void ja_job_clean_exec(ja_job_object* job) {
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s(),", __function_name);
 
-	zbx_snprintf(exec, sizeof(exec), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec");
-	dir = opendir(exec);
+	dir = opendir(JA_EXEC_FOLDER);
 	if (dir == NULL)
 	{
-		zabbix_log(LOG_LEVEL_ERR, "In %s, [%s] cannot be opened.", __function_name,exec);
+		zabbix_log(LOG_LEVEL_ERR, "In %s, [%s] cannot be opened.", __function_name,JA_EXEC_FOLDER);
 		return;
 
 	}
@@ -741,10 +706,10 @@ void ja_job_clean_exec(ja_job_object* job) {
 		if (strstr(entry->d_name, "-.job") != NULL) {
 			ja_job_object_init(job);
 			zbx_snprintf(filename, sizeof(filename), "%s", entry->d_name);
-			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec",JA_DLM,entry->d_name);
+			zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s", JA_EXEC_FOLDER,JA_DLM,entry->d_name);
 			zbx_snprintf(tmp_exec, strlen(filename)-4, "%s",filename);
 			zbx_snprintf(output_file, strlen(filename) - 3, "%s", filename);
-			zbx_snprintf(data_file, sizeof(data_file), "%s%c%s%c%s.json", CONFIG_TMPDIR, JA_DLM, "data",JA_DLM,tmp_exec);
+			zbx_snprintf(data_file, sizeof(data_file), "%s%c%s.json", JA_DATA_FOLDER,JA_DLM,tmp_exec);
 			if (read_datafile(job, data_file) == FAIL || NULL == job) {
 				zabbix_log(LOG_LEVEL_ERR, "In %s(), [%s] data file cannot be read.", __function_name,data_file);
 				continue;
@@ -770,8 +735,8 @@ void ja_job_clean_exec(ja_job_object* job) {
 				if (write_data_file(job, data_file) == FAIL) {
 					zabbix_log(LOG_LEVEL_ERR, "In %s() failed to write data on file.%s", __function_name, data_file);
 				}
-				zbx_snprintf(exec_file, sizeof(exec_file), "%s-",tmp_exec);
-				job_to_error(exec, exec_file);
+				zbx_snprintf(exec_file, sizeof(exec_file), "%s.job",exec_pid_file);
+				job_to_error(JA_EXEC_FOLDER, exec_file);
 			}
 
 		//end strstr.
