@@ -2,6 +2,7 @@
 ** Job Arranger for ZABBIX
 ** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
 ** Copyright (C) 2013 Daiwa Institute of Research Business Innovation Ltd. All Rights Reserved.
+** Copyright (C) 2021 Daiwa Institute of Research Ltd. All Rights Reserved.
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,11 +19,6 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-/*
-** $Date:: 2018-04-23 10:58:39 +0900 #$
-** $Revision: 7332 $
-** $Author: sypark@FITECHLABS.CO.JP $
-**/
 
 #ifndef JOBARG_EXECUTIVE_H
 #define JOBARG_EXECUTIVE_H
@@ -30,5 +26,12 @@
 #include "threads.h"
 
 ZBX_THREAD_ENTRY(executive_thread, args);
-
+int ja_job_check_beginfile(ja_job_object* job, ja_file_object* files);
+int ja_job_checkprocess(ja_job_object* job, ja_file_object* files);
+int ja_job_exec_end(ja_job_object* job, ja_file_object* files);
+int ja_job_exec_close(ja_job_object* job, ja_file_object* files);
+void get_current_time(char *current_time);
+int read_all_files(char *folder,ja_file_object *files,int *file_count);
+int ja_jobfile_chkend(const char *filepath, ja_job_object * job);
+void ja_job_clean_exec(ja_job_object* job);
 #endif
