@@ -210,8 +210,6 @@ int ja_agent_begin(ja_job_object* job, char* current_time, char* datafile)
     char jobid[JA_FILE_NAME_LEN];
     char full_filepath[JA_FILE_PATH_LEN];
     char filename[JA_FILE_PATH_LEN];
-    char folder[JA_FILE_PATH_LEN];
-    char data_folder[JA_FILE_PATH_LEN];
     char init_stat_file[JA_FILE_PATH_LEN];
     char* zero_pid = "-0000";
 
@@ -270,10 +268,7 @@ int ja_agent_begin(ja_job_object* job, char* current_time, char* datafile)
 
     case JA_AGENT_METHOD_KILL:
         zbx_snprintf(jobid, sizeof(jobid), ZBX_FS_UI64"-", job->jobid);
-        zbx_snprintf(folder, sizeof(folder), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec");
-        zbx_snprintf(data_folder, sizeof(data_folder), "%s%cdata", CONFIG_TMPDIR, JA_DLM);
         proc_run_flag = ja_jobfile_check_proc_kill(tmp_exec_file, jobid, job, "exec");
-        //proc_run_flag = ja_jobfile_check_processexist(tmp_exec_file, jobid);
         if (proc_run_flag == 1) {
 
             ja_jobfile_getpid_by_filename(tmp_exec_file, temp_pid);
@@ -306,13 +301,12 @@ int ja_agent_begin(ja_job_object* job, char* current_time, char* datafile)
         else {
             zabbix_log(LOG_LEVEL_WARNING, "In %s(), Job ["ZBX_FS_UI64"] is not running.", __function_name, job->jobid);
 
-            zbx_snprintf(folder, sizeof(folder), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "begin");
             proc_run_flag = ja_jobfile_check_proc_kill(tmp_exec_file, jobid, job, "begin");
             if(proc_run_flag == 1){
                 //set begin file name to -job
                 zbx_snprintf(filename, strlen(tmp_exec_file) - 3, "%s", tmp_exec_file);   //jobid-datetime
-                zbx_snprintf(init_stat_file, sizeof(init_stat_file), "%s%c%s-.job", folder, JA_DLM, filename);
-                zbx_snprintf(full_filepath, sizeof(full_filepath), "%s%c%s", folder,JA_DLM,tmp_exec_file);
+                zbx_snprintf(init_stat_file, sizeof(init_stat_file), "%s%c%s-.job", JA_BEGIN_FOLDER, JA_DLM, filename);
+                zbx_snprintf(full_filepath, sizeof(full_filepath), "%s%c%s", JA_BEGIN_FOLDER,JA_DLM,tmp_exec_file);
                 if (rename(full_filepath, init_stat_file) != 0) {
                     zabbix_log(LOG_LEVEL_ERR, "In %s(),[%s] job begin file cannot be renamed.%s", __function_name, tmp_exec_file, strerror(errno));
                     goto error;
@@ -382,7 +376,7 @@ error:
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int ja_agent_run(ja_job_object* job, char* data_filename)
+int ja_agent_run(ja_job_object* job, char* full_filename)
 {
     JA_PID pid;
     int        ret =SUCCEED;
@@ -408,12 +402,17 @@ int ja_agent_run(ja_job_object* job, char* data_filename)
 
     //Park.iggy END
     //ThihaOo@DAT start
+    size_t len;
     char data_filepath[JA_MAX_STRING_LEN];
     char data_file[JA_MAX_STRING_LEN];
     char tmp_exe_file[JA_MAX_STRING_LEN];
     char exec_file[JA_MAX_STRING_LEN];
     char tmp_filename[JA_MAX_STRING_LEN];
+    char data_filename[JA_FILE_NAME_LEN];
     //end
+
+    len = strlen(full_filename);
+    zbx_strlcpy(data_filename, full_filename, len - 3);
     zbx_snprintf(data_filepath, sizeof(data_filepath), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "data");
     zbx_snprintf(data_file, sizeof(data_file), "%s%c%s%s", data_filepath, JA_DLM, data_filename, ".json");
 
@@ -477,9 +476,9 @@ int ja_agent_run(ja_job_object* job, char* data_filename)
         zbx_snprintf(full_script, sizeof(full_script), "%s%s", env, job->script);
     }
     pid = getpid();
-    zbx_snprintf(filepath, sizeof(filepath), "%s%c%s%c%s%c", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, data_filename, '-');
-    zbx_snprintf(tmp_exe_file, sizeof(tmp_exe_file), "%s%c%s%c%s%c", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, data_filename);
-    zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, data_filename, "-.job");
+    zbx_snprintf(filepath, sizeof(filepath), "%s%c%s%c",JA_DATA_FOLDER, JA_DLM, data_filename, '-');
+    zbx_snprintf(tmp_exe_file, sizeof(tmp_exe_file), "%s%c%s%c", JA_EXEC_FOLDER, JA_DLM, data_filename);
+    zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%s", JA_EXEC_FOLDER, JA_DLM, data_filename, "-.job");
     if (ja_jobfile_create(filepath,full_script) == FAIL) {
         zabbix_log(LOG_LEVEL_ERR, "In %s() job data files creation failed. (%s)", __function_name, strerror(errno));
         zbx_snprintf(job->message, sizeof(job->message), "Can not create the result files [%s]", filepath);
@@ -636,9 +635,9 @@ int ja_agent_run(ja_job_object* job, char* data_filename)
     }
     else if (pid == 0) {
         job->pid = getpid();
-        zbx_snprintf(filepath, sizeof(filepath), "%s%c%s%c%s%c"ZBX_FS_UI64, CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, data_filename, '-', getpid());
-        zbx_snprintf(tmp_exe_file, sizeof(tmp_exe_file), "%s%c%s%c%s%s%d%s", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, data_filename, "-", getpid(), ".job");
-        zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, "exec", JA_DLM, data_filename, "-.job");
+        zbx_snprintf(filepath, sizeof(filepath), "%s%c%s%c"ZBX_FS_UI64, JA_DATA_FOLDER, JA_DLM, data_filename, '-', getpid());
+        zbx_snprintf(tmp_exe_file, sizeof(tmp_exe_file), "%s%c%s%s%d%s", JA_EXEC_FOLDER, JA_DLM, data_filename, "-", getpid(), ".job");
+        zbx_snprintf(exec_file, sizeof(exec_file), "%s%c%s%s", JA_EXEC_FOLDER, JA_DLM, data_filename, "-.job");
         if (job->method == JA_AGENT_METHOD_TEST) {
             ret = ja_jobfile_create(filepath,"");
         }
@@ -997,7 +996,7 @@ int ja_write_file_data(ja_job_object* job, char* current_time) {
     char* buf;
     int len, i = 0, j = 0;
     len = strlen(job->script);
-    buf = (char*)zbx_malloc(buf, len + 1);
+    buf = (char*)zbx_malloc(buf, len);
     for (i = 0; i < len; i++) {
         if ('\r' != job->script[i]) {
             buf[j] = job->script[i];
@@ -1181,8 +1180,8 @@ int job_to_end(char* filename,char* filename_pid,char *folder) {
         new_data_created[0] = '\0';
         while (FILE_EXT[i] != NULL) {
             if (i != 0) {
-                zbx_snprintf(data_created, sizeof(data_created), "%s%c%s%c%s-.%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, filename, FILE_EXT[i]);
-                zbx_snprintf(new_data_created, sizeof(new_data_created), "%s%c%s%c%s.%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, filename_pid, FILE_EXT[i]);
+                zbx_snprintf(data_created, sizeof(data_created), "%s%c%s-.%s", JA_DATA_FOLDER, JA_DLM, filename, FILE_EXT[i]);
+                zbx_snprintf(new_data_created, sizeof(new_data_created), "%s%c%s.%s", JA_DATA_FOLDER, JA_DLM, filename_pid, FILE_EXT[i]);
                 if (0 != rename(data_created, new_data_created)) {
                     zabbix_log(LOG_LEVEL_ERR, "In %s(),%s file cannot be renamed.(%s)", __function_name, data_created, strerror(errno));
                 }
@@ -1191,9 +1190,9 @@ int job_to_end(char* filename,char* filename_pid,char *folder) {
             i++;
         }
     }
-    zbx_snprintf(end, sizeof(end), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM, "end", JA_DLM, filename_pid, ".job");
+    zbx_snprintf(end, sizeof(end), "%s%c%s%s", JA_END_FOLDER, JA_DLM, filename_pid, ".job");
     zbx_snprintf(src, sizeof(src), "%s%c%s%c%s%s", CONFIG_TMPDIR, JA_DLM,folder, JA_DLM, filename, "-.job");
-    zbx_snprintf(start, sizeof(start), "%s%c%s%c%s.%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, filename_pid, FILE_EXT[2]);
+    zbx_snprintf(start, sizeof(start), "%s%c%s.%s", JA_DATA_FOLDER, JA_DLM, filename_pid, FILE_EXT[2]);
     if (0 != rename(src, end)) {
         zabbix_log(LOG_LEVEL_ERR, "In %s(),%s file cannot be moved.(%s)", __function_name, src, strerror(errno));
         return FAIL;
@@ -1260,7 +1259,7 @@ int ja_jobfile_check_proc_kill(char* filename, char* jobid_datetime,ja_job_objec
                     get_jobid_datetime(filename, pre_file);
                 }
             }
-            zbx_snprintf(data_file, sizeof(data_file), "%s%c%s%c%s.json", CONFIG_TMPDIR,JA_DLM,"data", JA_DLM, pre_file);
+            zbx_snprintf(data_file, sizeof(data_file), "%s%c%s.json", JA_DATA_FOLDER, JA_DLM, pre_file);
             if (read_datafile(tmp_job, data_file) == FAIL || NULL == tmp_job) {
                 zabbix_log(LOG_LEVEL_ERR, "In %s(), [%s] data file cannot be read.", __function_name, data_file);
                 break;
@@ -1297,7 +1296,7 @@ int ja_create_outputfile(char* output_file, int ext_cd) {
             i++;
             continue;
         }
-        zbx_snprintf(tmp_output, sizeof(tmp_output), "%s%c%s%c%s.%s", CONFIG_TMPDIR, JA_DLM, "data", JA_DLM, output_file, FILE_EXT[i]);
+        zbx_snprintf(tmp_output, sizeof(tmp_output), "%s%c%s.%s",JA_DATA_FOLDER, JA_DLM, output_file, FILE_EXT[i]);
         //set return code to ret file.
         if (i == 4) {
             fp = fopen(tmp_output, "wb");
