@@ -34,13 +34,13 @@
 #include "jafile.h"
 #include "jajobfile.h"
 #include "jajournal.h"
+#include <time.h>
 #ifdef _WINDOWS
 #include <dirent.h>
 #else
 #include <time.h>
 #endif
 
-
 /******************************************************************************
  *                                                                            *
  * Function:                                                                  *
@@ -81,7 +81,7 @@ ZBX_THREAD_ENTRY(jadbbackup_thread, args)
 		log_tm = localtime(&log_now);
 		if (0 == log_tm->tm_hour || 4 == log_tm->tm_hour || 8 == log_tm->tm_hour || 12 == log_tm->tm_hour || 16 == log_tm->tm_hour || 20 == log_tm->tm_hour) {
 			if (write_log == 0) {
-				zabbix_log(LOG_LEVEL_INFORMATION, "jobarg_agentd #%d running [jabackup]", thread_number);
+				zabbix_log(LOG_LEVEL_INFORMATION, "jobarg_agentd[%s (revision %s)] #%d running [jabackup]", JOBARG_VERSION, JOBARG_REVISION, thread_number);
 				write_log = 1;
 			}
 		}
@@ -91,7 +91,7 @@ ZBX_THREAD_ENTRY(jadbbackup_thread, args)
         if(CONFIG_BACKUP_RUN_TIME == 24){
 			remainder = time(NULL) % ((size_t)CONFIG_BACKUP_TIME * 3600);
         	if (remainder <= end_sleep) {
-        		zabbix_log(LOG_LEVEL_INFORMATION, "jabackup CONFIG_BACKUP_TIME[%d] time[%d]",CONFIG_BACKUP_TIME, remainder);
+        		zabbix_log(LOG_LEVEL_DEBUG, "jabackup CONFIG_BACKUP_TIME[%d] time[%d]",CONFIG_BACKUP_TIME, remainder);
         		zabbix_log(LOG_LEVEL_INFORMATION, "jabackup  CONFIG_BACKUP_TIME START BACKUP");
         		ja_datafile_remove_oldjob(CONFIG_JOB_HISTORY);
         		zabbix_log(LOG_LEVEL_INFORMATION, "jabackup  CONFIG_BACKUP_TIME END BACKUP");
@@ -100,7 +100,7 @@ ZBX_THREAD_ENTRY(jadbbackup_thread, args)
         	time(&now);
         	tm = localtime(&now);
         	if(tm->tm_min == 0  && CONFIG_BACKUP_RUN_TIME == tm->tm_hour && backup_flag == 0 ){
-        		zabbix_log(LOG_LEVEL_INFORMATION, "jabackup CONFIG_BACKUP_RUN_TIME [%d] current H[%d]  backup_flag[%d]",CONFIG_BACKUP_RUN_TIME,tm->tm_hour,backup_flag);
+        		zabbix_log(LOG_LEVEL_DEBUG, "jabackup CONFIG_BACKUP_RUN_TIME [%d] current H[%d]  backup_flag[%d]",CONFIG_BACKUP_RUN_TIME,tm->tm_hour,backup_flag);
         		backup_flag = 1;
         		zabbix_log(LOG_LEVEL_INFORMATION, "jabackup CONFIG_BACKUP_RUN_TIME START BACKUP");
         		ja_datafile_remove_oldjob(CONFIG_JOB_HISTORY);
@@ -120,11 +120,10 @@ ZBX_THREAD_ENTRY(jadbbackup_thread, args)
 int ja_datafile_remove_oldjob(int day)
 {	
 	const int total_data_file_count = 7;
-    int i, j, ii, jj, deleteFolder;
+    int i, j, ii, jj, deleteFolder, fail_count, success_count,to_error_count;
 	struct stat      stat_buf;
-	time_t history;
+	time_t history,start,diff;
 	char close_file[JA_FILE_PATH_LEN];
-	char close_filepath[JA_MAX_STRING_LEN];
 	char archive_folder[JA_FILE_PATH_LEN];
 	char archive_folder_name[JA_FILE_PATH_LEN];
 	char archive_file[JA_FILE_PATH_LEN];
@@ -137,13 +136,15 @@ int ja_datafile_remove_oldjob(int day)
 
     const char *__function_name = "ja_jobmain_remove_oldjob";
 
-
+	start = time(NULL);
+	fail_count = 0;
+	success_count = 0;
+	to_error_count = 0;
 
     zabbix_log(LOG_LEVEL_DEBUG, "In %s() day: %d", __function_name, day);
     history = time(NULL) - ((time_t)day * 24 * 60 * 60);
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s  history = %ld ", __function_name, history);
-	zbx_snprintf(close_filepath, sizeof(close_filepath), "%s%cclose", CONFIG_TMPDIR, JA_DLM);
-	close_dir = opendir(close_filepath);
+	close_dir = opendir(JA_CLOSE_FOLDER);
 	if (NULL == close_dir)
 	{
 		zabbix_log(LOG_LEVEL_ERR, "In %s(), Folder cannot be read.", __function_name);
@@ -154,23 +155,24 @@ int ja_datafile_remove_oldjob(int day)
 	{
 		
 		if (NULL != strstr(entry->d_name, ".job")) {
-			zbx_snprintf(close_file, sizeof(close_file), "%s%c%s", close_filepath, JA_DLM, entry->d_name);
+			zbx_snprintf(close_file, sizeof(close_file), "%s%c%s", JA_CLOSE_FOLDER, JA_DLM, entry->d_name);
 			if (stat(close_file, & stat_buf) == 0) {
 				zabbix_log(LOG_LEVEL_DEBUG, "In %s file[%s] modify time[%ld]", __function_name, close_file, stat_buf.st_mtime);
 				//check history time.
 				if ((history - stat_buf.st_mtime) > 0 ) {
 
-					zbx_snprintf(archive_file, sizeof(archive_file), "%s%c%s", close_filepath, JA_DLM, entry->d_name);
+					zbx_snprintf(archive_file, sizeof(archive_file), "%s%c%s", JA_CLOSE_FOLDER, JA_DLM, entry->d_name);
 					zbx_snprintf(archive_folder_name, strlen(entry->d_name) - 3, "%s", entry->d_name);
-					zbx_snprintf(archive_folder, sizeof(archive_folder), "%s%c%s", close_filepath, JA_DLM, archive_folder_name);
+					zbx_snprintf(archive_folder, sizeof(archive_folder), "%s%c%s", JA_CLOSE_FOLDER, JA_DLM, archive_folder_name);
 
 					//check if sub folder exists in close folder;
 					if (get_file_count(archive_folder) < total_data_file_count) {
 						zabbix_log(LOG_LEVEL_DEBUG, "In %s()  some files are missing or sub folder is not under close folder.Moving to error folder.", __function_name);
 						//move files from data and close/sub-folder to error folder.
-						if (job_to_error(close_filepath, archive_folder_name) == FAIL) {
+						if (job_to_error(JA_CLOSE_FOLDER, entry->d_name) == FAIL) {
 							zabbix_log(LOG_LEVEL_ERR, "In %s() [%s] data folder file delete failed. (%s)", __function_name, entry->d_name, strerror(errno));
 						}
+						to_error_count++;
 						continue;
 					}
 
@@ -202,7 +204,7 @@ int ja_datafile_remove_oldjob(int day)
 						else {
 							zabbix_log(LOG_LEVEL_ERR, "In %s() [%s] file close delete failed. (%s)", __function_name, del_file, strerror(errno));
 							//delete data file under /data folder if close/sub-folder data files cannot be removed.
-							zbx_snprintf(del_file, sizeof(del_file), "%s%cdata%c%s.%s", CONFIG_TMPDIR, JA_DLM, JA_DLM, data_file, FILE_EXT[i]);
+							zbx_snprintf(del_file, sizeof(del_file), "%s%c%s.%s",JA_DATA_FOLDER, JA_DLM, data_file, FILE_EXT[i]);
 							if (0 == remove(del_file)) {
 								zabbix_log(LOG_LEVEL_WARNING, "In %s() [%s] data folder file deleted.", __function_name, del_file);
 							}
@@ -224,7 +226,7 @@ int ja_datafile_remove_oldjob(int day)
 					j = 0;
 					deleteFolder = rmdir(archive_folder);
 					if (0 == deleteFolder) {
-						zabbix_log(LOG_LEVEL_INFORMATION, "In %s() [%s] deleted folder.", __function_name, archive_folder_name);
+						zabbix_log(LOG_LEVEL_DEBUG, "In %s() [%s] deleted folder.", __function_name, archive_folder_name);
 						j = 1;
 					}
 					else {
@@ -238,19 +240,24 @@ int ja_datafile_remove_oldjob(int day)
 						}
 					}
 					if (1 == j && 0 == remove(close_file)) {
-						zabbix_log(LOG_LEVEL_DEBUG, "In %s() deleted [%s] job file.", __function_name, close_file);
+						zabbix_log(LOG_LEVEL_INFORMATION, "In %s() deleted [%s] job file.", __function_name, entry->d_name);
+						success_count++;
 					}
 					else {
 						zabbix_log(LOG_LEVEL_ERR, "In %s() [%s] job file, delete failed. (%s)", __function_name, close_file, strerror(errno));
+						fail_count++;
 					}
 				}
 			}
 			else {
-				zabbix_log(LOG_LEVEL_ERR, "In %s(), file cannot be read.[%s]", __function_name, close_file);
+				zabbix_log(LOG_LEVEL_ERR, "In %s() file cannot be read.[%s]", __function_name, close_file);
 			}
 		}
 	}
 	closedir(close_dir);
-
+	zabbix_log(LOG_LEVEL_INFORMATION, "Delete: %d success, %d fail",success_count,fail_count);
+	zabbix_log(LOG_LEVEL_INFORMATION, "Moved under error dir : % d", to_error_count);
+	diff = time(NULL) - start;
+	zabbix_log(LOG_LEVEL_INFORMATION, "Execution time : %ld sec.", diff);
     return SUCCEED;
-}
\ No newline at end of file
+}
