@@ -39,6 +39,7 @@
 #include "executive.h"
 #include "jobarg_agentd.h"
 #include "jadbbackup.h"
+#include "jajobfile.h"
 
 #include <dirent.h>
 
@@ -251,6 +252,10 @@ static void set_defaults()
 
     if (NULL == CONFIG_TMPDIR)
         CONFIG_TMPDIR = zbx_strdup(CONFIG_TMPDIR, "/var/lib/jobarranger/tmp");
+
+	
+    if (NULL == CONFIG_LOG_TYPE_STR)
+        CONFIG_LOG_TYPE_STR = zbx_strdup(CONFIG_LOG_TYPE_STR, "file");
 }
 
 /******************************************************************************
@@ -282,6 +287,7 @@ static void jobarg_load_config(int requirement)
         {"Timeout",           &CONFIG_TIMEOUT,             TYPE_INT,    PARM_OPT,  1,   300},
         {"DebugLevel",        &CONFIG_LOG_LEVEL,           TYPE_INT,    PARM_OPT,  0,   4},
         {"LogFileSize",       &CONFIG_LOG_FILE_SIZE,       TYPE_INT,    PARM_OPT,  0,   1024},
+        {"LogType",           &CONFIG_LOG_TYPE_STR,        TYPE_STRING, PARM_OPT,  0,   0},
         {"JaLogFile",         &CONFIG_LOG_FILE,            TYPE_STRING, PARM_OPT,  0,   0},
         {"JaServerPort",      &CONFIG_SERVER_PORT,         TYPE_INT,    PARM_OPT,  1,   65535},
         {"JaListenPort",      &CONFIG_LISTEN_PORT,         TYPE_INT,    PARM_OPT,  1,   65535},
@@ -327,6 +333,14 @@ static void jobarg_load_config(int requirement)
     CONFIG_REBOOT_FILE =
         zbx_dsprintf(NULL, "%s%c%s", CONFIG_EXTJOB_PATH, JA_DLM,
                      JA_JOBARG_REBOOT);
+    //set config tmp dir with /tmp/[begin/close/data/end/error/execute] folder path to global variables.
+    zbx_snprintf(JA_DATA_FOLDER, sizeof(JA_DATA_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "data");
+    zbx_snprintf(JA_BEGIN_FOLDER, sizeof(JA_BEGIN_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "begin");
+    zbx_snprintf(JA_EXEC_FOLDER, sizeof(JA_EXEC_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "exec");
+    zbx_snprintf(JA_ERROR_FOLDER, sizeof(JA_ERROR_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "error");
+    zbx_snprintf(JA_CLOSE_FOLDER, sizeof(JA_CLOSE_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "close");
+    zbx_snprintf(JA_END_FOLDER, sizeof(JA_END_FOLDER), "%s%c%s", CONFIG_TMPDIR, JA_DLM, "end");
+
 }
 
 /******************************************************************************
@@ -404,7 +418,7 @@ int MAIN_ZABBIX_ENTRY()
     int status;
 #endif
 	
-	if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
+    if (strcmp(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_SYSTEM) == 0 || NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
         zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
     } else {
         zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
