@@ -110,7 +110,7 @@ static int process_listener(zbx_sock_t * s,ja_job_object * job, ja_job_object *
         	//Added by ThihaOo@DAT 11/01/2021
         	if(job->method !=JA_AGENT_METHOD_KILL){
                 //check for job ID and server ID.
-                zbx_snprintf(jobid_datetime, sizeof(jobid_datetime), ZBX_FS_UI64"-%s", job->jobid, current_time);
+                zbx_snprintf(jobid_datetime, sizeof(jobid_datetime), ZBX_FS_UI64"-%s.job", job->jobid, current_time);
                 proc_run_flag = ja_jobfile_check_processexist(filename,jobid_datetime);// 0: No running process; 1: Running process
                 //if the same jobid from same server is running, 
                 if (proc_run_flag == 1) {
@@ -121,7 +121,7 @@ static int process_listener(zbx_sock_t * s,ja_job_object * job, ja_job_object *
                     }
                     int datafile_read_flg = SUCCEED;
                     get_jobid_datetime(filename, data_filename);
-                    zbx_snprintf(full_datafile_path, sizeof(full_datafile_path), "%s%cdata%c%s.json", CONFIG_TMPDIR, JA_DLM,JA_DLM,data_filename);
+                    zbx_snprintf(full_datafile_path, sizeof(full_datafile_path), "%s%c%s.json", JA_DATA_FOLDER,JA_DLM,data_filename);
                     datafile_read_flg = read_datafile(temp_job, full_datafile_path);
                     if (datafile_read_flg != FAIL && temp_job != NULL && strncmp(job->serverip,temp_job->serverip,sizeof(job->serverip)) != 0) {
                         zbx_snprintf(job->message, sizeof(job->message), "Job with same job id is already running.");
@@ -144,7 +144,7 @@ static int process_listener(zbx_sock_t * s,ja_job_object * job, ja_job_object *
             	}
         	}
         	//End
-            zbx_snprintf(data_file, sizeof(data_file), "%s%cdata%c" ZBX_FS_UI64 "-%s.json", CONFIG_TMPDIR, JA_DLM, JA_DLM, job->jobid, current_time);
+            zbx_snprintf(data_file, sizeof(data_file), "%s%c" ZBX_FS_UI64 "-%s.json", JA_DATA_FOLDER, JA_DLM, job->jobid, current_time);
             zabbix_log(LOG_LEVEL_DEBUG, "In %s() job type is : %s and data file is : %s", __function_name,job->type,data_file);
             if (ja_agent_begin(job,&current_time, & data_file) != SUCCEED) {
                 zabbix_log(LOG_LEVEL_ERR, "In %s() job id :"ZBX_FS_UI64" job agent begin failed.", __function_name, job->jobid);
@@ -217,7 +217,7 @@ ZBX_THREAD_ENTRY(listener_thread, args)
         tm = localtime(&now);
         if (0 == tm->tm_hour || 4 == tm->tm_hour || 8 == tm->tm_hour || 12 == tm->tm_hour || 16 == tm->tm_hour || 20 == tm->tm_hour) {
             if (write_log == 0) {
-                zabbix_log(LOG_LEVEL_INFORMATION, "jobarg_agentd #%d running [listener]", thread_number);
+                zabbix_log(LOG_LEVEL_INFORMATION, "jobarg_agentd[%s (revision %s)] #%d running [listener]", JOBARG_VERSION, JOBARG_REVISION, thread_number);
                 write_log = 1;
             }
         }
