@@ -111,7 +111,6 @@ int  CONFIG_LOG_SLOW_QUERIES       = 0;
 int  CONFIG_PROXYCONFIG_FREQUENCY  = 0;
 int  CONFIG_PROXYDATA_FREQUENCY    = 0;
 
-char *CONFIG_LOG_TYPE_STR ;
 
 /******************************************************************************
  *                                                                            *
@@ -245,6 +244,10 @@ static void ja_load_config(const char *config_file)
     if (NULL == CONFIG_PID_FILE) {
         CONFIG_PID_FILE = zbx_strdup(CONFIG_PID_FILE, "/var/run/jobarranger/jobarg_monitor.pid");
     }
+
+    if (NULL == CONFIG_LOG_TYPE_STR) {
+        CONFIG_LOG_TYPE_STR = zbx_strdup(CONFIG_LOG_TYPE_STR, "file");
+    }
 }
 
 /******************************************************************************
@@ -378,7 +381,7 @@ int ja_sender(const int id, const char *schedule_id, const char *jobnet_id,
 
     zabbix_log(LOG_LEVEL_INFORMATION, "In %s() cmd: %s", __function_name, cmd);
 
-    ret = system(cmd);
+    ret = ja_system_call(cmd);
     if (ret != 0) {
         if (WIFEXITED(ret)) {
             state = WEXITSTATUS(ret);
@@ -536,7 +539,7 @@ int MAIN_ZABBIX_ENTRY()
     }
     if (0 == console_flag)
     {
-    	if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
+    	if (strcmp(CONFIG_LOG_TYPE_STR,ZBX_OPTION_LOGTYPE_SYSTEM) == 0 || NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE) {
     		zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
     	}
     	else {
