@@ -477,8 +477,7 @@ static int    message_send(ja_zbxsnd_info_t *zbxsnd)
                      now_time, msg_type, log_message_id, log_message, user_name, host_name, jobnet_id, job_id_full, inner_jobnet_main_id);
 
         /* command execution */
-        state = system(cmd);
-
+        state = ja_system_call(cmd);
         zabbix_log(LOG_LEVEL_DEBUG, "application execution [%s] (%d)", cmd, state);
 
         time(&now);
