@@ -611,7 +611,7 @@ int jarun_icon_extjob_zbxsender(const zbx_uint64_t inner_job_id, char *value)
 
     /* zabbix_sender execution */
     zbx_snprintf(full_command, sizeof(full_command), "%s -vv %s > %s/%s." ZBX_FS_UI64 " 2>&1 &", cmd, value, CONFIG_TMPDIR, JA_EXTJOB_RESULT_FILE, inner_job_id);
-    rc = system(full_command);
+    rc = ja_system_call(full_command);
 
     zabbix_log(LOG_LEVEL_DEBUG, "zabbix_sender execution [%s] (%d)", full_command, rc);
 
