@@ -141,7 +141,7 @@ int jarun_icon_less(const zbx_uint64_t inner_job_id, const int test_flag)
              /* start the session management process */
              zbx_snprintf(cmd, sizeof(cmd), "%s/jobarg_session -S '%s' -r '" ZBX_FS_UI64 "' -T '%d' -c '%s' &",
                           CONFIG_EXTJOB_PATH, session_id, inner_jobnet_main_id, test_flag, CONFIG_FILE);
-             rc = system(cmd);
+            rc = ja_system_call(cmd);
              zabbix_log(LOG_LEVEL_DEBUG, "jobarg_session execution [%s] (%d)", cmd, rc);
              if (rc != EXIT_SUCCESS) {
                  if (WIFEXITED(rc)) {
