@@ -97,7 +97,7 @@ char *jarun_icon_zabbixlink_get_trigger_message(const zbx_uint64_t inner_job_id,
     zabbix_log(LOG_LEVEL_DEBUG, "In %s() inner_job_id: " ZBX_FS_UI64, __function_name, inner_job_id);
 
     result = DBselect("select u.lang from ja_run_jobnet_table j, ja_run_job_table jb, users u"
-                      " where u.alias = j.execution_user_name"
+                      " where u.username = j.execution_user_name"
                       " and j.inner_jobnet_id = jb.inner_jobnet_main_id"
                       " and jb.inner_job_id = " ZBX_FS_UI64,
                       inner_job_id);
@@ -1573,7 +1573,7 @@ int jarun_icon_zabbixlink_check_access_permission(const zbx_uint64_t inner_jobne
     execution_user_name_esc = DBdyn_escape_string(row[0]);
     DBfree_result(result);
 
-    result = DBselect("select type from users where alias = '%s'",execution_user_name_esc);
+    result = DBselect("select r.type from users u,role r where u.username = '%s' and r.roleid = u.roleid",execution_user_name_esc);
     if (NULL != (row = DBfetch(result))) {
     	/* Zabbix Super Admin check */
     	if(atoi(row[0]) == 3 ){
@@ -1589,7 +1589,7 @@ int jarun_icon_zabbixlink_check_access_permission(const zbx_uint64_t inner_jobne
     res = 0;
     /* get access privileges on the host group */
     result = DBselect("select c.permission from users a, users_groups b, rights c"
-                      " where c.id = %s and b.usrgrpid = c.groupid and a.userid = b.userid and a.alias = '%s'",
+                      " where c.id = %s and b.usrgrpid = c.groupid and a.userid = b.userid and a.username = '%s'",
                       group_id, execution_user_name_esc);
 
     while (NULL != (row = DBfetch(result))) {
