@@ -189,7 +189,6 @@ int	CONFIG_PROXYPOLLER_FORKS	= 1;	/* parameters for passive proxies */
 int	CONFIG_PROXYCONFIG_FREQUENCY	= 3600;	/* 1h */
 int	CONFIG_PROXYDATA_FREQUENCY	= 1;	/* 1s */
 
-char *CONFIG_LOG_TYPE_STR ;
 /* mutex for node syncs */
 //ZBX_MUTEX	node_sync_access;
 
@@ -253,6 +252,9 @@ static void zbx_set_defaults()
 
 	if (NULL == CONFIG_TMPDIR)
 		CONFIG_TMPDIR = zbx_strdup(CONFIG_TMPDIR, "tmp");
+
+	if (NULL == CONFIG_LOG_TYPE_STR)
+		CONFIG_LOG_TYPE_STR = zbx_strdup(CONFIG_LOG_TYPE_STR,"file");
 }
 
 /******************************************************************************
@@ -451,7 +453,7 @@ int MAIN_ZABBIX_ENTRY()
 
 	if (0 == console_flag)
 	{
-		if (NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE)
+		if (strcmp(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_SYSTEM) == 0 ||NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE)
 			zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
 		else
 			zabbix_open_log(LOG_TYPE_FILE, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
