@@ -270,6 +270,9 @@ static void parse_commandline(int argc, char **argv)
     if (CONFIG_FILE == NULL) {
         CONFIG_FILE = zbx_strdup(CONFIG_FILE, SYSCONFDIR "/jobarg_server.conf");
     }
+    if (CONFIG_LOG_TYPE_STR == NULL){
+		CONFIG_LOG_TYPE_STR = zbx_strdup(CONFIG_LOG_TYPE_STR,"file");
+    }
 }
 
 /******************************************************************************
@@ -301,6 +304,7 @@ static void ja_load_config(const char *config_file)
         {"Timeout",              &CONFIG_TIMEOUT,              TYPE_INT,     PARM_OPT,   1,     300},
         {"DebugLevel",           &CONFIG_LOG_LEVEL,            TYPE_INT,     PARM_OPT,   0,     4},
         {"LogFileSize",          &CONFIG_LOG_FILE_SIZE,        TYPE_INT,     PARM_OPT,   0,     1024},
+		{"LogType",			     &CONFIG_LOG_TYPE_STR,	       TYPE_STRING,	 PARM_OPT,	 0,	    0},
         {"JaLogFile",            &CONFIG_LOG_FILE,             TYPE_STRING,  PARM_OPT,   0,     0},
         {"JaAgentListenPort",    &CONFIG_AGENT_LISTEN_PORT,    TYPE_INT,     PARM_OPT,   1,     65535},
         {"JaErrorCmdPath",       &CONFIG_ERROR_CMD_PATH,       TYPE_STRING,  PARM_MAND,  0,     0},
@@ -1727,11 +1731,13 @@ int main(int argc, char **argv)
     progname = get_program_name(argv[0]);
     parse_commandline(argc, argv);
     ja_load_config(CONFIG_FILE);
-
-    zabbix_open_log(LOG_TYPE_FILELOG, CONFIG_LOG_LEVEL, NULL);
-
+    if (strcmp(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_SYSTEM) == 0 ||NULL == CONFIG_LOG_FILE || '\0' == *CONFIG_LOG_FILE){
+		zabbix_open_log(LOG_TYPE_SYSLOG, CONFIG_LOG_LEVEL, NULL);
+    }
+	else{
+		zabbix_open_log(LOG_TYPE_FILELOG, CONFIG_LOG_LEVEL, CONFIG_LOG_FILE);
+    }
     ja_log("JASESSION000001", 0, NULL, 0, JOBARG_SESSION_ID, JOBARG_REGISTRY_NUMBER, JOBARG_TEST_FLAG);
-
     init_agentless_info();
 
     DBconnect(ZBX_DB_CONNECT_NORMAL);
