@@ -1611,7 +1611,7 @@ const char	*zbx_user_string(zbx_uint64_t userid)
 	DB_RESULT	result;
 	DB_ROW		row;
 
-	result = DBselect("select name,surname,alias from users where userid=" ZBX_FS_UI64,
+	result = DBselect("select name,surname,username from users where userid=" ZBX_FS_UI64,
 			userid);
 
 	if (NULL != (row = DBfetch(result)))
