@@ -259,7 +259,12 @@ int	daemon_start(int allow_root)
 
 		if (-1 == chdir("/"))	/* this is to eliminate warning: ignoring return value of chdir */
 			assert(0);
-		redirect_std(CONFIG_LOG_FILE);
+
+		//if background and log type system, redirect std to syslog.
+		if ( NULL != CONFIG_LOG_FILE && '\0' != *CONFIG_LOG_FILE && strcmp(CONFIG_LOG_TYPE_STR, ZBX_OPTION_LOGTYPE_FILE) == 0){
+			redirect_std(CONFIG_LOG_FILE);
+    	}
+		
 	}
 
 	if (FAIL == create_pid_file(CONFIG_PID_FILE))
